# Guidelines for contributing to this project

Any constructive contributions &ndash; bug reports, pull requests (code or documentation), suggestions for improvements, and more &ndash; are welcome.

When contributing to this repository, please first discuss the change you wish to make via issue, email, or any other method with the owners of this repository before making a change.

## Procedure

Our default branch is **master** which should be used for branching/forking and creating Pull Requests. 

## General:

* For code contributions, please adhere to the
  [PEP8 style guide](https://www.python.org/dev/peps/pep-0008/)
* All new functionality should be covered by unit tests
* Please document all modules, functions, classes, attributes, arguments,
  return values, ... in a style consistent with the rest of the library
* Use descriptive commit messages

## Submitting contributions

To contribute to this repository:

Please feel free to contact the author directly, or even better, jump right in and use the standard GitHub approach of forking the repo and creating a pull request.

* Create a pull request

  *By creating a pull request you agree with your contribution being made
  available under the license terms specified in
  [https://github.com/copasi/basico/blob/master/LICENSE).*

* Assign a reviewer, or let us know otherwise, that your pull request is ready
  for review.

* Wait for feedback (and feel free so send a gentle reminder if you did not
  get any feedback within a week)
